xml_object_mapping library

Classes

BoolConverter
A converter for transforming XML string values to bool and vice versa.
DateTimeConverter
A converter for transforming XML string values to DateTime and vice versa.
DoubleConverter
A converter for transforming XML string values to double and vice versa.
EnumConverter<T extends Enum>
A converter for transforming XML string values to Enum and vice versa.
File
A reference to a file on the file system.
IntConverter
A converter for transforming XML string values to int and vice versa.
NumConverter
A converter for transforming XML string values to num and vice versa.
XmlConverter<T>
A converter for transforming XML string values to Dart types and vice versa.
XmlDocument
XML document node.
XmlElement
XML element node.
XmlMap
Marks a class for XML mapping code generation.
XmlMapAttribute
Maps an XML attribute to a field.
XmlMapElement
Maps an XML element to a field.
XmlMapList
Maps repeated XML elements to a List field.
XmlMapValue
Maps the content of an XML element to a field.
XmlValueConverter
Default converter for String types.

Constants

xmlMap → const XmlMap
A constant annotation instance for marking classes for XML mapping code generation.
xmlMapAttribute → const XmlMapAttribute
A constant annotation instance for mapping XML attributes to fields.
xmlMapElement → const XmlMapElement
A constant annotation instance for mapping XML elements to fields.
xmlMapValue → const XmlMapValue
A constant annotation instance for mapping XML element content to fields.

Exceptions / Errors

FileSystemException
Exception thrown when a file operation fails.
XmlMappingException
Base exception for XML mapping errors.
XmlMappingFormatException
Exception thrown when XML format is invalid.
XmlMappingMissingElementException
Exception thrown when a required XML element or attribute is missing.
XmlMappingParserException
Exception thrown when XML parsing fails.
XmlMappingTypeConversionException
Exception thrown when a type conversion fails.