XmlMapElement class

Maps an XML element to a field.

Constructors

XmlMapElement({String? overrideName, XmlConverter<String>? decorator, XmlConverter? converter})
const

Properties

converter XmlConverter?
Optional custom converter for this field.
final
decorator XmlConverter<String>?
Optional decorator for this field.
final
hashCode int
The hash code for this object.
no setterinherited
overrideName String?
Optional override name for the XML element.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited